@@ -5,6 +5,7 @@ Date: 2021/12/9 19:05
 Desc: HTTP 模式主文件
 """
 import json
+import urllib.parse
 
 import akshare as ak
 from fastapi import FastAPI, Request
@@ -24,18 +25,19 @@ async def root(request: Request, item_id: str):
     :rtype: json
     """
     interface_list = dir(ak)
+    decode_params = urllib.parse.unquote(str(request.query_params))
     if item_id not in interface_list:
         return {'error': '没有该接口'}
-    eval_str = str(request.query_params).replace("&", '", ').replace("=", '="') + '"'
+    eval_str = decode_params.replace("&", '", ').replace("=", '="') + '"'
     if not bool(request.query_params):
         try:
-            temp_df = eval("ak." + item_id + f"()").to_json(orient='records')
+            temp_df = eval("ak." + item_id + f"()").to_json(orient='records', date_format='iso')
         except KeyError as e:
             return {'error': '参数错误'}
         return json.loads(temp_df)
     else:
         try:
-            temp_df = eval("ak." + item_id + f"({eval_str})").to_json(orient='records')
+            temp_df = eval("ak." + item_id + f"({eval_str})").to_json(orient='records', date_format='iso')
         except KeyError as e:
             return {'error': f'请输入正确的参数错误 {e} '}
         return json.loads(temp_df)
